@@ -1,4 +1,4 @@
-import { parseCodeCell, parseStepsFromCells } from '@boyuai/jupyter-helper';
+import { IQuestion, parseCodeCell, parseStepsFromCells } from '@boyuai/jupyter-helper';
 import { parseQuestionOptions } from '@boyuai/jupyter-helper/lib/quiz';
 import { getQuizQuestionByUUID, parseQuizQuestions } from './services';
 import { ICell, IJupyter } from './types';
@@ -352,6 +352,7 @@ basepath = os.path.expanduser('~/share/bby/')
 };
 
 const syncLesson = async function () {
+  // 注意这边导出了 JSON，所以下面怎么改都和原对象无关，如果同步时修改了数据，重开才能读到
   const content = Jupyter.notebook.toJSON();
 
   const pathRegRes = workRegx.exec(Jupyter.notebook.notebook_path);
@@ -388,7 +389,6 @@ const syncLesson = async function () {
     })
       .then((response) => {
         if (response.ok) {
-          Jupyter.notebook.save_notebook();
           alert('同步成功，请刷新博小鱼步骤页后查看，中途请不要运行代码');
         } else {
           response.json().then((res) => {
@@ -458,13 +458,13 @@ const syncLesson = async function () {
             });
             // console.log('来自题库的 quiz question', { questionJSON });
             if (!questionJSON.uuid) {
-              throw new Error(`Quiz 解析失败: 题库题目 ${uuid} 解析异常`);
+              throw new Error(`Quiz 解析失败: 题目 ${question.id} 解析异常`);
             }
             const questionIndex = quizJSON.value.findIndex(
-              (option: any) => option.id === `uuid-${uuid}`
+              (option: IQuestion) => option.id === question.id
             );
             if (questionIndex === -1) {
-              throw new Error(`Quiz 解析失败: 题库题目 ${uuid} 匹配失败`);
+              throw new Error(`Quiz 解析失败: 题目 ${question.id} 匹配失败`);
             }
             // console.log('开始更新 quiz quetion', {
             //   questionWIP: quizJSON.value[questionIndex],
@@ -472,7 +472,7 @@ const syncLesson = async function () {
             const options = parseQuestionOptions(questionJSON);
             quizJSON.value[questionIndex] = {
               ...questionJSON,
-              id: questionJSON.uuid,
+              id: question.id,
               options,
             };
             console.log('quiz quetion 更新完成', {
